==> core-1.23.0-sources.jar: software/amazon/awscdk/core/Aws.java <==
package software.amazon.awscdk.core;

/**
 * Accessor for pseudo parameters.
 * <p>
 * Since pseudo parameters need to be anchored to a stack somewhere in the
 * construct tree, this class takes an scope parameter; the pseudo parameter
 * values can be obtained as properties from an scoped object.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.21.2 (build 4370756)", date = "2020-02-07T03:00:46.296Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Aws")
public class Aws extends software.amazon.jsii.JsiiObject {

    protected Aws(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Aws(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ACCOUNT_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "ACCOUNT_ID", java.lang.String.class);
        NO_VALUE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "NO_VALUE", java.lang.String.class);
        NOTIFICATION_ARNS = java.util.Collections.unmodifiableList(software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "NOTIFICATION_ARNS", java.util.List.class));
        PARTITION = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "PARTITION", java.lang.String.class);
        REGION = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "REGION", java.lang.String.class);
        STACK_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "STACK_ID", java.lang.String.class);
        STACK_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "STACK_NAME", java.lang.String.class);
        URL_SUFFIX = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "URL_SUFFIX", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String ACCOUNT_ID;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String NO_VALUE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.util.List<java.lang.String> NOTIFICATION_ARNS;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PARTITION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String REGION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String STACK_ID;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String STACK_NAME;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String URL_SUFFIX;
}

==> core-1.24.0-sources.jar: software/amazon/awscdk/core/Aws.java <==
package software.amazon.awscdk.core;

/**
 * Accessor for pseudo parameters.
 * <p>
 * Since pseudo parameters need to be anchored to a stack somewhere in the
 * construct tree, this class takes an scope parameter; the pseudo parameter
 * values can be obtained as properties from an scoped object.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.22.0 (build 14afdde)", date = "2020-02-13T18:53:47.514Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.core.$Module.class, fqn = "@aws-cdk/core.Aws")
public class Aws extends software.amazon.jsii.JsiiObject {

    protected Aws(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Aws(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        ACCOUNT_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "ACCOUNT_ID", java.lang.String.class);
        NO_VALUE = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "NO_VALUE", java.lang.String.class);
        NOTIFICATION_ARNS = java.util.Collections.unmodifiableList(software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "NOTIFICATION_ARNS", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        PARTITION = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "PARTITION", java.lang.String.class);
        REGION = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "REGION", java.lang.String.class);
        STACK_ID = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "STACK_ID", java.lang.String.class);
        STACK_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "STACK_NAME", java.lang.String.class);
        URL_SUFFIX = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.core.Aws.class, "URL_SUFFIX", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String ACCOUNT_ID;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String NO_VALUE;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.util.List<java.lang.String> NOTIFICATION_ARNS;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String PARTITION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String REGION;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String STACK_ID;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String STACK_NAME;

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static java.lang.String URL_SUFFIX;
}
